@@ -1,5 +1,5 @@
 import os
-from sqlalchemy import create_engine, Column, Text, SmallInteger, Integer, TIMESTAMP, Array
+from sqlalchemy import create_engine, Column, Text, SmallInteger, Integer, TIMESTAMP, ARRAY
 from sqlalchemy.ext.declarative import declarative_base
 from sqlalchemy.orm import sessionmaker, scoped_session
 
@@ -54,7 +54,7 @@ class TSDatabase(Database):
             __tablename__ = 'recommendations'
             time = Column(TIMESTAMP, primary_key=True)
             user_id = Column(Text, primary_key=True)
-            recommendations = Array(Text)
+            recommendations = ARRAY(Text)
         return Recommendation
     
     def _create_view_class(self, base):
